
==========
Enum Types
==========

.. autosummary::
    :nosignatures:
    :toctree: _generated/

    rompy_swan.types.IDLA
    rompy_swan.types.GridOptions
    rompy_swan.types.BoundShapeOptions
    rompy_swan.types.SideOptions
    rompy_swan.types.PhysicsOff
    rompy_swan.types.BlockOptions